import streamlit as st
from __init__ import chips_tags

st.set_page_config(layout="centered")

title="Probability Equipment will be in category"
data = [
            {"index":0, "label":"Attack", "value":""},
            {"index":1, "label":"Magic", "value":""},
            {"index":2, "label":"Defense", "value":""},
            {"index":3, "label":"Movement", "value":""},
            {"index":4, "label":"Roaming", "value":""},
            {"index":5, "label":"Jungling", "value":""},
        ]

styles_ = {
    "chips-container": {
        "white-space":"wrap",
        "display":"flex",
        "flex-direction":"row",
        "justify-content":"flex-start",
        "align-items":"flex-start",
        "flex-wrap":"wrap",
        "row-gap":"5px"
    },
    # "the-chip": {
    #     "flex":"1"
    # }
}

cols = st.columns([3,4])
with cols[0]:
    val_ = chips_tags(data, styles=styles_, title=None)

with cols[1]:
    st.subheader("James is here")





import os
import streamlit as st
import streamlit.components.v1 as components

_RELEASE = True 

if not _RELEASE:
    _chips_tags = components.declare_component(

        "chips_tags",
        url="http://localhost:3001",

    )
else:
    # build directory:
    parent_dir = os.path.dirname(os.path.abspath(__file__))
    build_dir = os.path.join(parent_dir, "frontend/build")
    _chips_tags = components.declare_component("chips_tags", path=build_dir)

def chips_tags(data=None, styles=None, title=None, default=None, key="foo"):
    """
    Args:
    - data: array of dicts
        args:
        - index
        - label
        - value
    - styles: css styles to add to html elements
    - title: title of the tags
    """

    value = _chips_tags(data=data, styles=styles, title=title, default=default, key=key)

    return value